@@ -1,12 +1,8 @@
 use serde_json::{json, Value};
-use shumai::{bench_config, Context, ShumaiBench, ShumaiResult};
+use shumai::{shumai_config, Context, ShumaiBench, ShumaiResult};
 
-#[bench_config]
+#[shumai_config]
 pub mod test_config {
-    use serde::{Deserialize, Serialize};
-    use shumai::ShumaiConfig;
-
-    #[derive(ShumaiConfig, Serialize, Deserialize, Clone, Debug)]
     pub struct Foo {
         pub name: String,
         pub threads: Vec<usize>,
@@ -14,6 +10,12 @@ pub mod test_config {
         #[matrix]
         pub a: usize,
     }
+
+    pub struct Bar {
+        pub name: String,
+        pub threads: Vec<usize>,
+        pub time: usize,
+    }
 }
 
 #[derive(Debug, PartialEq)]
@@ -32,14 +34,14 @@ struct TestBench {
 
 impl ShumaiBench for TestBench {
     type Result = usize;
-    type Config = Foo;
+    type Config = test_config::Foo;
 
     fn load(&mut self) -> Option<Value> {
         self.execution_queue.push(ExecutionSeq::Load);
         Some(json!({"load_finished": true}))
     }
 
-    fn run(&self, context: Context<Foo>) -> Self::Result {
+    fn run(&self, context: Context<test_config::Foo>) -> Self::Result {
         context.wait_for_start();
         let mut sum = 0;
         while context.is_running() {
@@ -79,6 +81,12 @@ fn config() {
     assert_eq!(config.len(), 1);
 }
 
+#[test]
+#[should_panic(expected = "Failed to parse config!")]
+fn empty_config() {
+    test_config::Bar::load("tests/benchmark.toml").expect("Failed to parse config!");
+}
+
 #[test]
 #[cfg_attr(miri, ignore)]
 fn runner() {
@@ -147,7 +155,8 @@ fn write_json() {
         let file_path = result.write_json().unwrap();
 
         let written_data = std::fs::read_to_string(file_path).unwrap();
-        let result: ShumaiResult<Foo, usize> = serde_json::from_str(&written_data).unwrap();
+        let result: ShumaiResult<test_config::Foo, usize> =
+            serde_json::from_str(&written_data).unwrap();
         assert_eq!(result.config.time, 1);
         assert_eq!(result.config.threads, vec![1, 2, 3]);
         assert_eq!(result.bench_results.len(), 3);
